"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PostgresBatchEntityWriter = void 0;
const index_1 = require("../../common/index");
/**
 * @class
 * Class that writes data in batches of a specified size in PostgreSQL databases.
 * @extends AbstractBatchEntityWriterStream
 * @template T
 */
class PostgresBatchEntityWriter extends index_1.AbstractBatchEntityWriterStream {
    /**
     * @constructor
     * @param {PostgresBatchEntityWriterOptions} options - The options for the PostgresBatchEntityWriter.
     * @param [options.pool] {Pool} - The PostgreSQL connection pool.
     */
    constructor(options) {
        super(options);
        this.pool = options.pool;
    }
    /**
     * Writes a batch of data to the storage.
     *
     * @protected
     * @param {BatchData<T>} chunk - The batch of data to write to the storage.
     * @returns {Promise<void>}
     */
    async batchWrite(chunk) {
        const client = await this.pool.connect();
        try {
            await client.query("BEGIN");
            for (const entity of chunk) {
                await this.saveEntity(entity, client);
            }
            await client.query("COMMIT");
        }
        catch (error) {
            await client.query("ROLLBACK");
            return Promise.reject(error);
        }
        finally {
            client.release();
        }
    }
}
exports.PostgresBatchEntityWriter = PostgresBatchEntityWriter;
