import { AbstractBatchEntityWriterStream } from "../../common/index";
/**
 * @class
 * Class that writes data in batches of a specified size in MariadbQL databases.
 * @extends AbstractBatchEntityWriterStream
 * @template T input chunk
 * @template E row entity
 */
export class MariadbBatchEntityWriter extends AbstractBatchEntityWriterStream {
    /**
     * @constructor
     * @param {MariadbBatchEntityWriterOptions} options - The options for the MariadbBatchEntityWriter.
     * @param [options.pool] {Pool} - The MariadbQL connection pool.
     * @param [options.prepareStatement] {String} - Insert SQL prepared statement to be executed.
     */
    constructor(options) {
        super(options);
        this.pool = options.pool;
        this.prepareStatement = options.prepareStatement;
    }
    /**
     * Writes a batch of data to the storage.
     *
     * @protected
     * @param {BatchData<T>} chunk - The batch of data to write to the storage.
     * @returns {Promise<void>}
     */
    async batchWrite(chunk) {
        const client = await this.pool.getConnection();
        try {
            await client.beginTransaction();
            await client.batch(this.prepareStatement, chunk.map(this.entityToRow));
            await client.commit();
        }
        catch (error) {
            await client.rollback();
            return Promise.reject(error);
        }
        finally {
            client.release();
        }
    }
}
